Learn R Programming

rqubic (version 1.18.0)

readBiclusterResults: Import bicluster results from plain text files

Description

This function complements the functionality of writeBiclusterResults in the biclust package. It constructs a Biclust object from a plain text file.

Usage

readBiclusterResults(filename, featureNames, sampleNames, delimiter = ";", ...)

Arguments

filename
Character, name of the file storing biclustering information
featureNames
Optional character vector, feature names of the underlying expression dataset. See details.
sampleNames
Optional character vector, sample names of the underlying expression dataset. See details.
delimiter
Character used to separate features, samples and counts of them.
...
Other parameters passed to the readLines function.

Value

A Biclust object

Details

Currently output files written by the writeBiclusterResults function does not contain original feature names or sample names in the expression dataset from which biclusters were mined. The featureNames and sampleNames allow to use this information to construct a Biclust object that has the same dimension as the original expression dataset.

See Also

In case several biclustering algorithms were applied to the same expression dataset, they can be combined with combineBiclusts once the results were read from plain texts.

Examples

Run this code
temp <- tempfile()
library(biclust)
data(BicatYeast, package="biclust")
res <- biclust(BicatYeast, method=BCBimax(), number=5)
writeBiclusterResults(temp, res,"CC with delta 1.5",dimnames(BicatYeast)[[1]],dimnames(BicatYeast)[[2]], delimiter=";")
res.back <- readBiclusterResults(temp, delimiter=";")
res.full.back <- readBiclusterResults(temp,featureNames=rownames(BicatYeast), sampleNames=colnames(BicatYeast),delimiter=";")

Run the code above in your browser using DataLab